from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from ..google.api import field_behavior_pb2 as _field_behavior_pb2
from ..google.api import resource_pb2 as _resource_pb2
from ..google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Dataset(_message.Message):
    __slots__ = ("name", "display_name", "create_time", "state", "status", "example_count", "access_policy", "user_uploaded", "evaluation_result", "fireworks_traced", "draft_model_states", "transformed", "external_url", "format", "created_by", "update_time")
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[Dataset.State]
        UPLOADING: _ClassVar[Dataset.State]
        READY: _ClassVar[Dataset.State]
    STATE_UNSPECIFIED: Dataset.State
    UPLOADING: Dataset.State
    READY: Dataset.State
    class AccessPolicy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PRIVATE: _ClassVar[Dataset.AccessPolicy]
        PUBLIC: _ClassVar[Dataset.AccessPolicy]
    PRIVATE: Dataset.AccessPolicy
    PUBLIC: Dataset.AccessPolicy
    class Format(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        FORMAT_UNSPECIFIED: _ClassVar[Dataset.Format]
        CHAT: _ClassVar[Dataset.Format]
        COMPLETION: _ClassVar[Dataset.Format]
        RL: _ClassVar[Dataset.Format]
    FORMAT_UNSPECIFIED: Dataset.Format
    CHAT: Dataset.Format
    COMPLETION: Dataset.Format
    RL: Dataset.Format
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    EXAMPLE_COUNT_FIELD_NUMBER: _ClassVar[int]
    ACCESS_POLICY_FIELD_NUMBER: _ClassVar[int]
    USER_UPLOADED_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_RESULT_FIELD_NUMBER: _ClassVar[int]
    FIREWORKS_TRACED_FIELD_NUMBER: _ClassVar[int]
    DRAFT_MODEL_STATES_FIELD_NUMBER: _ClassVar[int]
    TRANSFORMED_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_URL_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    create_time: _timestamp_pb2.Timestamp
    state: Dataset.State
    status: _status_pb2.Status
    example_count: int
    access_policy: Dataset.AccessPolicy
    user_uploaded: UserUploaded
    evaluation_result: EvaluationResult
    fireworks_traced: FireworksTraced
    draft_model_states: DraftModelStates
    transformed: Transformed
    external_url: str
    format: Dataset.Format
    created_by: str
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., state: _Optional[_Union[Dataset.State, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., example_count: _Optional[int] = ..., access_policy: _Optional[_Union[Dataset.AccessPolicy, str]] = ..., user_uploaded: _Optional[_Union[UserUploaded, _Mapping]] = ..., evaluation_result: _Optional[_Union[EvaluationResult, _Mapping]] = ..., fireworks_traced: _Optional[_Union[FireworksTraced, _Mapping]] = ..., draft_model_states: _Optional[_Union[DraftModelStates, _Mapping]] = ..., transformed: _Optional[_Union[Transformed, _Mapping]] = ..., external_url: _Optional[str] = ..., format: _Optional[_Union[Dataset.Format, str]] = ..., created_by: _Optional[str] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class PreviewDatasetRequest(_message.Message):
    __slots__ = ("name", "page_size", "page_token", "filter", "order_by")
    NAME_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    name: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, name: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class PreviewDatasetResponse(_message.Message):
    __slots__ = ("examples", "next_page_token", "total_count")
    EXAMPLES_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    examples: _containers.RepeatedCompositeFieldContainer[Example]
    next_page_token: str
    total_count: int
    def __init__(self, examples: _Optional[_Iterable[_Union[Example, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_count: _Optional[int] = ...) -> None: ...

class Example(_message.Message):
    __slots__ = ("content",)
    CONTENT_FIELD_NUMBER: _ClassVar[int]
    content: str
    def __init__(self, content: _Optional[str] = ...) -> None: ...

class UserUploaded(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class Transformed(_message.Message):
    __slots__ = ("source_dataset_id", "filter", "original_format")
    SOURCE_DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORIGINAL_FORMAT_FIELD_NUMBER: _ClassVar[int]
    source_dataset_id: str
    filter: str
    original_format: Dataset.Format
    def __init__(self, source_dataset_id: _Optional[str] = ..., filter: _Optional[str] = ..., original_format: _Optional[_Union[Dataset.Format, str]] = ...) -> None: ...

class FireworksTraced(_message.Message):
    __slots__ = ("model", "base_model", "start_time", "end_time")
    MODEL_FIELD_NUMBER: _ClassVar[int]
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    START_TIME_FIELD_NUMBER: _ClassVar[int]
    END_TIME_FIELD_NUMBER: _ClassVar[int]
    model: str
    base_model: str
    start_time: _timestamp_pb2.Timestamp
    end_time: _timestamp_pb2.Timestamp
    def __init__(self, model: _Optional[str] = ..., base_model: _Optional[str] = ..., start_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., end_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class DraftModelStates(_message.Message):
    __slots__ = ("base_model",)
    BASE_MODEL_FIELD_NUMBER: _ClassVar[int]
    base_model: str
    def __init__(self, base_model: _Optional[str] = ...) -> None: ...

class EvaluationResult(_message.Message):
    __slots__ = ("evaluation_job_id",)
    EVALUATION_JOB_ID_FIELD_NUMBER: _ClassVar[int]
    evaluation_job_id: str
    def __init__(self, evaluation_job_id: _Optional[str] = ...) -> None: ...

class GetDatasetRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class CreateDatasetRequest(_message.Message):
    __slots__ = ("parent", "dataset", "dataset_id", "source_dataset_id", "filter")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    SOURCE_DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    parent: str
    dataset: Dataset
    dataset_id: str
    source_dataset_id: str
    filter: str
    def __init__(self, parent: _Optional[str] = ..., dataset: _Optional[_Union[Dataset, _Mapping]] = ..., dataset_id: _Optional[str] = ..., source_dataset_id: _Optional[str] = ..., filter: _Optional[str] = ...) -> None: ...

class UpdateDatasetRequest(_message.Message):
    __slots__ = ("dataset", "update_mask")
    DATASET_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    dataset: Dataset
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, dataset: _Optional[_Union[Dataset, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class UploadDatasetRequest(_message.Message):
    __slots__ = ("name", "filename_to_size")
    class FilenameToSizeEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    FILENAME_TO_SIZE_FIELD_NUMBER: _ClassVar[int]
    name: str
    filename_to_size: _containers.ScalarMap[str, int]
    def __init__(self, name: _Optional[str] = ..., filename_to_size: _Optional[_Mapping[str, int]] = ...) -> None: ...

class UploadDatasetResponse(_message.Message):
    __slots__ = ("filename_to_signed_urls",)
    class FilenameToSignedUrlsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FILENAME_TO_SIGNED_URLS_FIELD_NUMBER: _ClassVar[int]
    filename_to_signed_urls: _containers.ScalarMap[str, str]
    def __init__(self, filename_to_signed_urls: _Optional[_Mapping[str, str]] = ...) -> None: ...

class GetDatasetUploadEndpointRequest(_message.Message):
    __slots__ = ("name", "filename_to_size")
    class FilenameToSizeEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: int
        def __init__(self, key: _Optional[str] = ..., value: _Optional[int] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    FILENAME_TO_SIZE_FIELD_NUMBER: _ClassVar[int]
    name: str
    filename_to_size: _containers.ScalarMap[str, int]
    def __init__(self, name: _Optional[str] = ..., filename_to_size: _Optional[_Mapping[str, int]] = ...) -> None: ...

class GetDatasetUploadEndpointResponse(_message.Message):
    __slots__ = ("filename_to_signed_urls",)
    class FilenameToSignedUrlsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FILENAME_TO_SIGNED_URLS_FIELD_NUMBER: _ClassVar[int]
    filename_to_signed_urls: _containers.ScalarMap[str, str]
    def __init__(self, filename_to_signed_urls: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ValidateDatasetUploadRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetDatasetDownloadEndpointRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...

class GetDatasetDownloadEndpointResponse(_message.Message):
    __slots__ = ("filename_to_signed_urls",)
    class FilenameToSignedUrlsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    FILENAME_TO_SIGNED_URLS_FIELD_NUMBER: _ClassVar[int]
    filename_to_signed_urls: _containers.ScalarMap[str, str]
    def __init__(self, filename_to_signed_urls: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ListDatasetsRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ...) -> None: ...

class ListDatasetsResponse(_message.Message):
    __slots__ = ("datasets", "next_page_token", "total_size")
    DATASETS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    datasets: _containers.RepeatedCompositeFieldContainer[Dataset]
    next_page_token: str
    total_size: int
    def __init__(self, datasets: _Optional[_Iterable[_Union[Dataset, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class DeleteDatasetRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/model.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13gateway/model.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\x05\n\x05Model\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x01\x12\x18\n\x0b\x64\x65scription\x18\x14 \x01(\tB\x03\xe0\x41\x01\x12\x37\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12+\n\x05state\x18\x06 \x01(\x0e\x32\x14.gateway.Model.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x07 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12)\n\x04kind\x18\x04 \x01(\x0e\x32\x13.gateway.Model.KindB\x06\xe0\x41\x01\xe0\x41\x05\x12\x1d\n\rdeployment_id\x18\x0f \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x17\n\ngithub_url\x18\x15 \x01(\tB\x03\xe0\x41\x01\x12\x1d\n\x10hugging_face_url\x18\x16 \x01(\tB\x03\xe0\x41\x01\x12=\n\x12\x62\x61se_model_details\x18\x17 \x01(\x0b\x32\x19.gateway.BaseModelDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0cpeft_details\x18\x10 \x01(\x0b\x32\x14.gateway.PEFTDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x32\n\x0cteft_details\x18\x11 \x01(\x0b\x32\x14.gateway.TEFTDetailsB\x06\xe0\x41\x01\xe0\x41\x05\x12\x13\n\x06public\x18\x13 \x01(\x08\x42\x03\xe0\x41\x01\"k\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\r\n\tUPLOADING\x10\x01\x12\x0e\n\nUNDEPLOYED\x10\x02\x12\x0f\n\x0bUNDEPLOYING\x10\x03\x12\r\n\tDEPLOYING\x10\x04\x12\x0c\n\x08\x44\x45PLOYED\x10\x05\"U\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x11\n\rHF_BASE_MODEL\x10\x01\x12\x11\n\rHF_PEFT_ADDON\x10\x02\x12\x11\n\rHF_TEFT_ADDON\x10\x03\"\xf4\x01\n\x10\x42\x61seModelDetails\x12\x1a\n\nworld_size\x18\x01 \x01(\x05\x42\x06\xe0\x41\x01\xe0\x41\x05\x12M\n\x11\x63heckpoint_format\x18\x02 \x01(\x0e\x32*.gateway.BaseModelDetails.CheckpointFormatB\x06\xe0\x41\x01\xe0\x41\x05\x12!\n\x11huggingface_files\x18\x03 \x03(\tB\x06\xe0\x41\x01\xe0\x41\x05\"R\n\x10\x43heckpointFormat\x12!\n\x1d\x43HECKPOINT_FORMAT_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x0f\n\x0bHUGGINGFACE\x10\x02\"\\\n\x0bPEFTDetails\x12\x1a\n\nbase_model\x18\x01 \x01(\tB\x06\xe0\x41\x02\xe0\x41\x05\x12\x11\n\x01r\x18\x02 \x01(\x05\x42\x06\xe0\x41\x02\xe0\x41\x05\x12\x1e\n\x0etarget_modules\x18\x03 \x03(\tB\x06\xe0\x41\x02\xe0\x41\x05\"$\n\x0bTEFTDetails\x12\x15\n\x08has_teft\x18\x01 \x01(\x08\x42\x03\xe0\x41\x02\"d\n\x12\x43reateModelRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\"\n\x05model\x18\x02 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\x12\x15\n\x08model_id\x18\x03 \x01(\tB\x03\xe0\x41\x02\"$\n\x0fGetModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"C\n\x12\x44\x65ployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x1a\n\rdeployment_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\")\n\x14UndeployModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\xc4\x01\n\x1dGetModelUploadEndpointRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12Y\n\x10\x66ilename_to_size\x18\x02 \x03(\x0b\x32:.gateway.GetModelUploadEndpointRequest.FilenameToSizeEntryB\x03\xe0\x41\x02\x1a\x35\n\x13\x46ilenameToSizeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\xc1\x01\n\x1eGetModelUploadEndpointResponse\x12\x62\n\x17\x66ilename_to_signed_urls\x18\x05 \x03(\x0b\x32\x41.gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry\x1a;\n\x19\x46ilenameToSignedUrlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x1aValidateModelUploadRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x85\x01\n\x11ListModelsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"a\n\x12ListModelsResponse\x12\x1e\n\x06models\x18\x01 \x03(\x0b\x32\x0e.gateway.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"8\n\x12UpdateModelRequest\x12\"\n\x05model\x18\x01 \x01(\x0b\x32\x0e.gateway.ModelB\x03\xe0\x41\x02\"\'\n\x12\x44\x65leteModelRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_MODEL_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.Model.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPLOADING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEPLOYED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNDEPLOYING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPLOYING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEPLOYED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=666,
  serialized_end=773,
)
_sym_db.RegisterEnumDescriptor(_MODEL_STATE)

_MODEL_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='gateway.Model.Kind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KIND_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HF_BASE_MODEL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HF_PEFT_ADDON', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HF_TEFT_ADDON', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=775,
  serialized_end=860,
)
_sym_db.RegisterEnumDescriptor(_MODEL_KIND)

_BASEMODELDETAILS_CHECKPOINTFORMAT = _descriptor.EnumDescriptor(
  name='CheckpointFormat',
  full_name='gateway.BaseModelDetails.CheckpointFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHECKPOINT_FORMAT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NATIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUGGINGFACE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1025,
  serialized_end=1107,
)
_sym_db.RegisterEnumDescriptor(_BASEMODELDETAILS_CHECKPOINTFORMAT)


_MODEL = _descriptor.Descriptor(
  name='Model',
  full_name='gateway.Model',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Model.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_name', full_name='gateway.Model.display_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='gateway.Model.description', index=2,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Model.create_time', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.Model.state', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.Model.status', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='gateway.Model.kind', index=6,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment_id', full_name='gateway.Model.deployment_id', index=7,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='github_url', full_name='gateway.Model.github_url', index=8,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hugging_face_url', full_name='gateway.Model.hugging_face_url', index=9,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_model_details', full_name='gateway.Model.base_model_details', index=10,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peft_details', full_name='gateway.Model.peft_details', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='teft_details', full_name='gateway.Model.teft_details', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='public', full_name='gateway.Model.public', index=13,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MODEL_STATE,
    _MODEL_KIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=860,
)


_BASEMODELDETAILS = _descriptor.Descriptor(
  name='BaseModelDetails',
  full_name='gateway.BaseModelDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='world_size', full_name='gateway.BaseModelDetails.world_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint_format', full_name='gateway.BaseModelDetails.checkpoint_format', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='huggingface_files', full_name='gateway.BaseModelDetails.huggingface_files', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BASEMODELDETAILS_CHECKPOINTFORMAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=863,
  serialized_end=1107,
)


_PEFTDETAILS = _descriptor.Descriptor(
  name='PEFTDetails',
  full_name='gateway.PEFTDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_model', full_name='gateway.PEFTDetails.base_model', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='r', full_name='gateway.PEFTDetails.r', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_modules', full_name='gateway.PEFTDetails.target_modules', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1201,
)


_TEFTDETAILS = _descriptor.Descriptor(
  name='TEFTDetails',
  full_name='gateway.TEFTDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='has_teft', full_name='gateway.TEFTDetails.has_teft', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1203,
  serialized_end=1239,
)


_CREATEMODELREQUEST = _descriptor.Descriptor(
  name='CreateModelRequest',
  full_name='gateway.CreateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateModelRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='gateway.CreateModelRequest.model', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model_id', full_name='gateway.CreateModelRequest.model_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1341,
)


_GETMODELREQUEST = _descriptor.Descriptor(
  name='GetModelRequest',
  full_name='gateway.GetModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1379,
)


_DEPLOYMODELREQUEST = _descriptor.Descriptor(
  name='DeployModelRequest',
  full_name='gateway.DeployModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeployModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deployment_id', full_name='gateway.DeployModelRequest.deployment_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1381,
  serialized_end=1448,
)


_UNDEPLOYMODELREQUEST = _descriptor.Descriptor(
  name='UndeployModelRequest',
  full_name='gateway.UndeployModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.UndeployModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1491,
)


_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY = _descriptor.Descriptor(
  name='FilenameToSizeEntry',
  full_name='gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry.value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1637,
  serialized_end=1690,
)

_GETMODELUPLOADENDPOINTREQUEST = _descriptor.Descriptor(
  name='GetModelUploadEndpointRequest',
  full_name='gateway.GetModelUploadEndpointRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetModelUploadEndpointRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename_to_size', full_name='gateway.GetModelUploadEndpointRequest.filename_to_size', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1494,
  serialized_end=1690,
)


_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY = _descriptor.Descriptor(
  name='FilenameToSignedUrlsEntry',
  full_name='gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1827,
  serialized_end=1886,
)

_GETMODELUPLOADENDPOINTRESPONSE = _descriptor.Descriptor(
  name='GetModelUploadEndpointResponse',
  full_name='gateway.GetModelUploadEndpointResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename_to_signed_urls', full_name='gateway.GetModelUploadEndpointResponse.filename_to_signed_urls', index=0,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1693,
  serialized_end=1886,
)


_VALIDATEMODELUPLOADREQUEST = _descriptor.Descriptor(
  name='ValidateModelUploadRequest',
  full_name='gateway.ValidateModelUploadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.ValidateModelUploadRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1888,
  serialized_end=1935,
)


_LISTMODELSREQUEST = _descriptor.Descriptor(
  name='ListModelsRequest',
  full_name='gateway.ListModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListModelsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListModelsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListModelsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListModelsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListModelsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=2071,
)


_LISTMODELSRESPONSE = _descriptor.Descriptor(
  name='ListModelsResponse',
  full_name='gateway.ListModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='models', full_name='gateway.ListModelsResponse.models', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListModelsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListModelsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2073,
  serialized_end=2170,
)


_UPDATEMODELREQUEST = _descriptor.Descriptor(
  name='UpdateModelRequest',
  full_name='gateway.UpdateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='gateway.UpdateModelRequest.model', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2172,
  serialized_end=2228,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
  name='DeleteModelRequest',
  full_name='gateway.DeleteModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteModelRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2230,
  serialized_end=2269,
)

_MODEL.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MODEL.fields_by_name['state'].enum_type = _MODEL_STATE
_MODEL.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_MODEL.fields_by_name['kind'].enum_type = _MODEL_KIND
_MODEL.fields_by_name['base_model_details'].message_type = _BASEMODELDETAILS
_MODEL.fields_by_name['peft_details'].message_type = _PEFTDETAILS
_MODEL.fields_by_name['teft_details'].message_type = _TEFTDETAILS
_MODEL_STATE.containing_type = _MODEL
_MODEL_KIND.containing_type = _MODEL
_BASEMODELDETAILS.fields_by_name['checkpoint_format'].enum_type = _BASEMODELDETAILS_CHECKPOINTFORMAT
_BASEMODELDETAILS_CHECKPOINTFORMAT.containing_type = _BASEMODELDETAILS
_CREATEMODELREQUEST.fields_by_name['model'].message_type = _MODEL
_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY.containing_type = _GETMODELUPLOADENDPOINTREQUEST
_GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size'].message_type = _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY
_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY.containing_type = _GETMODELUPLOADENDPOINTRESPONSE
_GETMODELUPLOADENDPOINTRESPONSE.fields_by_name['filename_to_signed_urls'].message_type = _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY
_LISTMODELSRESPONSE.fields_by_name['models'].message_type = _MODEL
_UPDATEMODELREQUEST.fields_by_name['model'].message_type = _MODEL
DESCRIPTOR.message_types_by_name['Model'] = _MODEL
DESCRIPTOR.message_types_by_name['BaseModelDetails'] = _BASEMODELDETAILS
DESCRIPTOR.message_types_by_name['PEFTDetails'] = _PEFTDETAILS
DESCRIPTOR.message_types_by_name['TEFTDetails'] = _TEFTDETAILS
DESCRIPTOR.message_types_by_name['CreateModelRequest'] = _CREATEMODELREQUEST
DESCRIPTOR.message_types_by_name['GetModelRequest'] = _GETMODELREQUEST
DESCRIPTOR.message_types_by_name['DeployModelRequest'] = _DEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name['UndeployModelRequest'] = _UNDEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name['GetModelUploadEndpointRequest'] = _GETMODELUPLOADENDPOINTREQUEST
DESCRIPTOR.message_types_by_name['GetModelUploadEndpointResponse'] = _GETMODELUPLOADENDPOINTRESPONSE
DESCRIPTOR.message_types_by_name['ValidateModelUploadRequest'] = _VALIDATEMODELUPLOADREQUEST
DESCRIPTOR.message_types_by_name['ListModelsRequest'] = _LISTMODELSREQUEST
DESCRIPTOR.message_types_by_name['ListModelsResponse'] = _LISTMODELSRESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelRequest'] = _UPDATEMODELREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelRequest'] = _DELETEMODELREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Model = _reflection.GeneratedProtocolMessageType('Model', (_message.Message,), {
  'DESCRIPTOR' : _MODEL,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Model)
  })
_sym_db.RegisterMessage(Model)

BaseModelDetails = _reflection.GeneratedProtocolMessageType('BaseModelDetails', (_message.Message,), {
  'DESCRIPTOR' : _BASEMODELDETAILS,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.BaseModelDetails)
  })
_sym_db.RegisterMessage(BaseModelDetails)

PEFTDetails = _reflection.GeneratedProtocolMessageType('PEFTDetails', (_message.Message,), {
  'DESCRIPTOR' : _PEFTDETAILS,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.PEFTDetails)
  })
_sym_db.RegisterMessage(PEFTDetails)

TEFTDetails = _reflection.GeneratedProtocolMessageType('TEFTDetails', (_message.Message,), {
  'DESCRIPTOR' : _TEFTDETAILS,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.TEFTDetails)
  })
_sym_db.RegisterMessage(TEFTDetails)

CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

DeployModelRequest = _reflection.GeneratedProtocolMessageType('DeployModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeployModelRequest)
  })
_sym_db.RegisterMessage(DeployModelRequest)

UndeployModelRequest = _reflection.GeneratedProtocolMessageType('UndeployModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNDEPLOYMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UndeployModelRequest)
  })
_sym_db.RegisterMessage(UndeployModelRequest)

GetModelUploadEndpointRequest = _reflection.GeneratedProtocolMessageType('GetModelUploadEndpointRequest', (_message.Message,), {

  'FilenameToSizeEntry' : _reflection.GeneratedProtocolMessageType('FilenameToSizeEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY,
    '__module__' : 'gateway.model_pb2'
    # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointRequest.FilenameToSizeEntry)
    })
  ,
  'DESCRIPTOR' : _GETMODELUPLOADENDPOINTREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointRequest)
  })
_sym_db.RegisterMessage(GetModelUploadEndpointRequest)
_sym_db.RegisterMessage(GetModelUploadEndpointRequest.FilenameToSizeEntry)

GetModelUploadEndpointResponse = _reflection.GeneratedProtocolMessageType('GetModelUploadEndpointResponse', (_message.Message,), {

  'FilenameToSignedUrlsEntry' : _reflection.GeneratedProtocolMessageType('FilenameToSignedUrlsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY,
    '__module__' : 'gateway.model_pb2'
    # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry)
    })
  ,
  'DESCRIPTOR' : _GETMODELUPLOADENDPOINTRESPONSE,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetModelUploadEndpointResponse)
  })
_sym_db.RegisterMessage(GetModelUploadEndpointResponse)
_sym_db.RegisterMessage(GetModelUploadEndpointResponse.FilenameToSignedUrlsEntry)

ValidateModelUploadRequest = _reflection.GeneratedProtocolMessageType('ValidateModelUploadRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEMODELUPLOADREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ValidateModelUploadRequest)
  })
_sym_db.RegisterMessage(ValidateModelUploadRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'gateway.model_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)


DESCRIPTOR._options = None
_MODEL.fields_by_name['name']._options = None
_MODEL.fields_by_name['display_name']._options = None
_MODEL.fields_by_name['description']._options = None
_MODEL.fields_by_name['create_time']._options = None
_MODEL.fields_by_name['state']._options = None
_MODEL.fields_by_name['status']._options = None
_MODEL.fields_by_name['kind']._options = None
_MODEL.fields_by_name['deployment_id']._options = None
_MODEL.fields_by_name['github_url']._options = None
_MODEL.fields_by_name['hugging_face_url']._options = None
_MODEL.fields_by_name['base_model_details']._options = None
_MODEL.fields_by_name['peft_details']._options = None
_MODEL.fields_by_name['teft_details']._options = None
_MODEL.fields_by_name['public']._options = None
_BASEMODELDETAILS.fields_by_name['world_size']._options = None
_BASEMODELDETAILS.fields_by_name['checkpoint_format']._options = None
_BASEMODELDETAILS.fields_by_name['huggingface_files']._options = None
_PEFTDETAILS.fields_by_name['base_model']._options = None
_PEFTDETAILS.fields_by_name['r']._options = None
_PEFTDETAILS.fields_by_name['target_modules']._options = None
_TEFTDETAILS.fields_by_name['has_teft']._options = None
_CREATEMODELREQUEST.fields_by_name['parent']._options = None
_CREATEMODELREQUEST.fields_by_name['model']._options = None
_CREATEMODELREQUEST.fields_by_name['model_id']._options = None
_GETMODELREQUEST.fields_by_name['name']._options = None
_DEPLOYMODELREQUEST.fields_by_name['name']._options = None
_DEPLOYMODELREQUEST.fields_by_name['deployment_id']._options = None
_UNDEPLOYMODELREQUEST.fields_by_name['name']._options = None
_GETMODELUPLOADENDPOINTREQUEST_FILENAMETOSIZEENTRY._options = None
_GETMODELUPLOADENDPOINTREQUEST.fields_by_name['name']._options = None
_GETMODELUPLOADENDPOINTREQUEST.fields_by_name['filename_to_size']._options = None
_GETMODELUPLOADENDPOINTRESPONSE_FILENAMETOSIGNEDURLSENTRY._options = None
_VALIDATEMODELUPLOADREQUEST.fields_by_name['name']._options = None
_LISTMODELSREQUEST.fields_by_name['parent']._options = None
_LISTMODELSREQUEST.fields_by_name['page_size']._options = None
_LISTMODELSREQUEST.fields_by_name['page_token']._options = None
_LISTMODELSREQUEST.fields_by_name['filter']._options = None
_LISTMODELSREQUEST.fields_by_name['order_by']._options = None
_UPDATEMODELREQUEST.fields_by_name['model']._options = None
_DELETEMODELREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/wandb.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/wandb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13gateway/wandb.proto\x12\x07gateway\x1a\x1fgoogle/api/field_behavior.proto\"\x95\x01\n\x0bWandbConfig\x12\x15\n\x07\x65nabled\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x15\n\x07\x61pi_key\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x15\n\x07project\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x65ntity\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x06run_id\x18\x05 \x01(\tB\x06\x18\x01\xe2\x41\x01\x01\x12\x13\n\x03url\x18\x06 \x01(\tB\x06\xe2\x41\x03\x03\x05\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.wandb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_WANDBCONFIG'].fields_by_name['enabled']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['enabled']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['api_key']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['api_key']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['project']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['project']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['entity']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['entity']._serialized_options = b'\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['run_id']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['run_id']._serialized_options = b'\030\001\342A\001\001'
  _globals['_WANDBCONFIG'].fields_by_name['url']._loaded_options = None
  _globals['_WANDBCONFIG'].fields_by_name['url']._serialized_options = b'\342A\003\003\005\001'
  _globals['_WANDBCONFIG']._serialized_start=66
  _globals['_WANDBCONFIG']._serialized_end=215
# @@protoc_insertion_point(module_scope)



from fireworks.flumina.config import get_api_key, set_api_key
from fireworks.flumina.crud import (
    list_accounts,
    list_models,
    get_model,
    create_model,
    get_model_upload_endpoint,
    validate_model_upload,
    delete_model,
    list_deployments,
    get_deployment,
    create_deployment,
    delete_deployment,
    create_deployed_model,
)
from fireworks.flumina.exec import exec_flumina_script
from fireworks.flumina.logger import get_logger
from fireworks.flumina.openapi import generate_curl_commands
from fireworks.flumina.util import log_time

import argparse
import asyncio
from gitignore_parser import parse_gitignore
import httpx
import json
import importlib.resources
import os
import shutil
import socket
import stat
import sys
from tabulate import tabulate
import textwrap
import time
import traceback
import torch
import tqdm
from typing import Any, Dict, List, Optional, Tuple


def flumina_validate(args):
    file_path = os.getcwd()
    world_size = args.world_size
    master_addr = "127.0.0.1"
    master_port = _find_open_port()

    # Validate fireworks.json setup before spawning processes
    _validate_setup(file_path)

    # Determine available GPUs for round-robin assignment
    available_gpus = torch.cuda.device_count()
    if available_gpus < world_size:
        get_logger().warning(
            f"Requested {world_size} processes, but only {available_gpus} GPUs are available. "
            "Some processes will share the same GPU."
        )

    # Launch worker processes for validation using torch.multiprocessing
    processes = []
    try:
        # Spawn processes and add to the list
        torch.multiprocessing.spawn(
            flumina_worker,
            args=(file_path, world_size, master_addr, master_port, available_gpus),
            nprocs=world_size,
            join=True
        )
        print(
            "Flumina validation successful! Now you can upload the model to Fireworks "
            "with a command like `flumina deploy my-model-name`"
        )

    except KeyboardInterrupt:
        # Handle Ctrl+C gracefully by terminating all processes
        print("\nKeyboardInterrupt received. Terminating all subprocesses...")
        for p in processes:
            if p.is_alive():
                p.terminate()
        sys.exit(-1)

    except Exception as e:
        get_logger().error(f"Validation failed: {str(e)}")
        sys.exit(-1)

    finally:
        # Ensure that any remaining active subprocesses are killed
        for p in processes:
            if p.is_alive():
                p.terminate()


def _find_open_port():
    """Finds an open port on the host system."""
    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
        s.bind(('', 0))
        s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
        return s.getsockname()[1]

def _validate_setup(file_path):
    """Validates the fireworks.json and flumina.py setup before running validation."""
    with log_time("Validating fireworks.json"):
        fw_json_path = os.path.join(file_path, "fireworks.json")
        if not os.path.exists(fw_json_path):
            get_logger().error(
                "fireworks.json does not exist in the current directory. Ensure "
                "you have run flumina init in this directory"
            )
            sys.exit(-1)

        with open(fw_json_path, "r") as f:
            loaded_fw_json = json.load(f)
            if loaded_fw_json.get("_is_flumina_model", None) != True:
                get_logger().error(
                    "fireworks.json did not have correct _is_flumina_model. Ensure "
                    "you have run flumina init in this directory"
                )
                sys.exit(-1)

def flumina_worker(rank, file_path, world_size, master_addr, master_port, available_gpus):
    """Worker function to run exec_flumina_script in a distributed setting."""
    os.environ["RANK"] = str(rank)
    os.environ["WORLD_SIZE"] = str(world_size)
    os.environ["MASTER_ADDR"] = master_addr
    os.environ["MASTER_PORT"] = str(master_port)

    # Assign a CUDA device based on the rank (round-robin across available GPUs)
    cuda_device = rank % available_gpus
    torch.cuda.set_device(torch.device("cuda", cuda_device))

    script_path = os.path.join(file_path, "flumina.py")
    if not os.path.exists(script_path):
        get_logger().error(
            "flumina.py does not exist in the current directory. Ensure "
            "you have run flumina init in this directory"
        )
        sys.exit(-1)

    try:
        # Run the actual script validation
        exported_mod, _ = exec_flumina_script(script_path)

        if len(exported_mod.path_to_method_name) == 0:
            get_logger().error(
                "Flumina module did not define any endpoint paths. Ensure you "
                "define at least one path with the @path decorator on a method"
            )
            sys.exit(-1)

    except Exception as e:
        error_message = ''.join(traceback.format_exception(None, e, e.__traceback__))
        get_logger().error(f"Validation script failed on rank {rank}:\n{error_message}")
        sys.exit(-1)


def flumina_init_app(args):
    if os.listdir() and not args.allow_non_empty:
        get_logger().error(
            "Tried to initialize Flumina app in a non-empty directory. "
            "Pass --allow-non-empty to bypass this check"
        )
        sys.exit(-1)

    static_assets = {
        "flumina_py_template.txt": "flumina.py",
        "fluminaignore_template.txt": ".fluminaignore",
        "requirements.txt": "requirements.txt",
    }

    for template_filename, dest_filename in static_assets.items():
        with importlib.resources.open_text(
            "fireworks.flumina.assets", template_filename
        ) as f:
            flumina_py_template = f.read()

        cwd = os.getcwd()
        with open(os.path.join(cwd, dest_filename), "w") as f:
            f.write(flumina_py_template)

    fireworks_json = {"_is_flumina_model": True}
    with open(os.path.join(cwd, "fireworks.json"), "w") as f:
        json.dump(fireworks_json, f)

    os.mkdir(os.path.join(cwd, "data"))


def _copy_directory_contents(src_dir, dest_dir):
    # Ensure the destination directory exists
    if not os.path.exists(dest_dir):
        os.makedirs(dest_dir)

    # Loop through all files and directories in the source directory
    for item in os.listdir(src_dir):
        src_item = os.path.join(src_dir, item)
        dest_item = os.path.join(dest_dir, item)

        # If it's a directory, recursively copy it
        if os.path.isdir(src_item):
            shutil.copytree(src_item, dest_item, dirs_exist_ok=True)
        # If it's a file, copy it to the destination
        else:
            shutil.copy2(src_item, dest_item)


def flumina_init_from_hf(args):
    # Delegate to flumina_init to set up initial structure
    flumina_init(args)

    # Download specified model from HF hub
    try:
        from huggingface_hub import snapshot_download
    except ImportError as e:
        get_logger().exception("")
        get_logger().error(
            f"Failed to import huggingface_hub. Ensure you have it "
            f"installed, e.g. via pip install huggingface_hub"
        )

    snapshot_download_path = snapshot_download(repo_id=args.model_repo)

    cwd = os.getcwd()
    # Copy contents of snapshot_download_path into /data
    dest_data_dir = os.path.join(cwd, "data")
    _copy_directory_contents(src_dir=snapshot_download_path, dest_dir=dest_data_dir)

    # Best effort to try to detect the correct model class
    model_repo, model_classname = None, None

    model_index_json_path = os.path.join(dest_data_dir, "model_index.json")
    if os.path.exists(model_index_json_path):
        with open(model_index_json_path, "r") as f:
            loaded_model_index = json.load(f)

        if (
            loaded_model_index.get("_diffusers_version", None) is not None
            and loaded_model_index.get("_class_name", None) is not None
        ):
            model_repo = "diffusers"
            model_classname = loaded_model_index["_class_name"]

    # Overwrite flumina.py to contain the HF template
    with importlib.resources.open_text(
        "fireworks.flumina.assets", "flumina_hf_template.txt"
    ) as f:
        flumina_py_template = f.read()

    assert (model_repo is not None) == (model_classname is not None)
    if model_repo is not None:
        flumina_py_template = flumina_py_template.format(
            model_class_import_str=f"from {model_repo} import {model_classname}",
            model_classname_str=model_classname,
        )
    else:
        flumina_py_template = flumina_py_template.format(
            model_class_import_str="",
            model_classname_str="ModelClassname",
        )

    static_assets = {
        "fluminaignore_template.txt": ".fluminaignore",
        "requirements.txt": "requirements.txt",
    }

    for template_filename, dest_filename in static_assets.items():
        with importlib.resources.open_text(
            "fireworks.flumina.assets", template_filename
        ) as f:
            flumina_py_template = f.read()

        cwd = os.getcwd()
        with open(os.path.join(cwd, dest_filename), "w") as f:
            f.write(flumina_py_template)

    cwd = os.getcwd()
    with open(os.path.join(cwd, "flumina.py"), "w") as f:
        f.write(flumina_py_template)


def flumina_init_addon(args):
    if os.listdir() and not args.allow_non_empty:
        get_logger().error(
            "Tried to initialize Flumina app in a non-empty directory. "
            "Pass --allow-non-empty to bypass this check"
        )
        sys.exit(-1)

    fireworks_json = {
        "_is_flumina_model": True,
        "_flumina_addon_type": args.addon_type,
    }
    with open("fireworks.json", "w") as f:
        json.dump(fireworks_json, f)

    static_assets = {
        "fluminaignore_template.txt": ".fluminaignore",
    }

    for template_filename, dest_filename in static_assets.items():
        with importlib.resources.open_text(
            "fireworks.flumina.assets", template_filename
        ) as f:
            flumina_py_template = f.read()

        cwd = os.getcwd()
        with open(os.path.join(cwd, dest_filename), "w") as f:
            f.write(flumina_py_template)


def extract_components_from_resource_id(path, resource_type: str = "models"):
    # Split the string by '/'
    components = path.split("/")

    # Ensure the format is as expected
    if (
        len(components) >= 4
        and components[0] == "accounts"
        and components[2] == resource_type
    ):
        # Extract the 2nd and 4th components
        second_component = components[1]  # "fireworks"
        fourth_component = components[3]  # "flux-1-dev-controlnet-union"

        return second_component, fourth_component
    else:
        raise ValueError(
            f"Expected resource name in the format accounts/{{account_id}}/{resource_type}/{{resource_id}} "
            f"but got {path}"
        )


def resolve_user_scoped_resource_name(
    name: str, user_account_id: str, resource_type: str
):
    if "/" not in name:
        return user_account_id, name

    account_id, resource_id = extract_components_from_resource_id(name, resource_type)
    return account_id, resource_id


def generate_url(
    model_acct_id: str,
    model_id: str,
    deployment_account_id: Optional[str] = None,
    deployment_id: Optional[str] = None,
    path_override: Optional[str] = None,
):
    if path_override is not None:
        url = f"https://api.fireworks.ai/inference{path_override}"
    else:
        url = f"https://api.fireworks.ai/inference/v1/workflows/accounts/{model_acct_id}/models/{model_id}"

    if deployment_account_id is not None:
        assert deployment_id is not None
        url = f"{url}?deployment=accounts/{deployment_account_id}/deployments/{deployment_id}"

    return url


def _account_id_from_account_name(account_name: str):
    keyword, account_id = account_name.split("/")
    assert keyword == "accounts"
    return account_id


async def resolve_account_id(args):
    # Fetch the list of accounts
    accounts = await list_accounts()

    # Extract account IDs from the account names
    account_ids = [
        _account_id_from_account_name(account["name"])
        for account in accounts["accounts"]
    ]

    # If only one account exists, return it automatically
    if len(account_ids) == 1:
        return account_ids[0]

    # If there are multiple accounts, prompt the user to select one
    print("Please select an account ID from the following options:")
    for idx, account_id in enumerate(account_ids, 1):
        print(f"{idx}. {account_id}")

    # Keep prompting the user until a valid selection is made
    while True:
        try:
            selection = int(input("Enter the number of the account to select: ")) - 1
            if 0 <= selection < len(account_ids):
                return account_ids[selection]
            else:
                print(
                    f"Invalid selection. Please enter a number between 1 and {len(account_ids)}."
                )
        except ValueError:
            print("Invalid input. Please enter a number.")


# Models CRUD
async def _flumina_list_models(args):
    account_id = await resolve_account_id(args)

    models = []

    response_json = await list_models(account_id=account_id)
    models.extend(response_json["models"])
    pageToken = response_json.get("nextPageToken", "")

    while pageToken != "":
        response_json = await list_models(account_id, pageToken=pageToken)
        models.extend(response_json["models"])
        pageToken = response_json.get("nextPageToken", "")

    # account_id, model_id
    to_fetch: List[Tuple[str, str]] = []

    for m in models:
        if m["kind"] not in {"FLUMINA_BASE_MODEL", "FLUMINA_ADDON"}:
            continue

        (
            account_id,
            model_id,
        ) = extract_components_from_resource_id(m["name"])
        to_fetch.append((account_id, model_id))

    gathered_models: List[Dict[str, Any]] = await asyncio.gather(
        *[get_model(account_id, model_id) for account_id, model_id in to_fetch]
    )

    headers = ["account_id", "model_id", "state", "base_model_id", "url_prefix"]
    results: List[Tuple[str, str, str, str, str]] = []

    for m in gathered_models:
        account_id, model_id = extract_components_from_resource_id(m["name"])

        state = m["state"]
        if m["peftDetails"] is not None:
            base_model_account_id, base_model_id = extract_components_from_resource_id(
                m["name"]
            )
            base_model_name = f"{base_model_account_id}/{base_model_id}"
        else:
            base_model_name = ""

        default_deployment: Dict[str, Any] = None
        for ref in m["deployedModelRefs"]:
            if ref["default"]:
                default_deployment = ref
                break

        if default_deployment is not None:
            url_prefix = generate_url(account_id, model_id)
        else:
            url_prefix = f"<no default deployment>"

        results.append((account_id, model_id, state, base_model_name, url_prefix))

    # Print the table
    print(tabulate(results, headers=headers, tablefmt="plain"))


def flumina_list_models(args):
    return asyncio.run(_flumina_list_models(args))


async def _flumina_get_model(args):
    user_account_id = await resolve_account_id(args)
    model_account_id, model_id = resolve_user_scoped_resource_name(
        args.model_name, user_account_id, resource_type="models"
    )

    response_json = await get_model(account_id=model_account_id, model_id=model_id)

    print(json.dumps(response_json))


def flumina_get_model(args):
    return asyncio.run(_flumina_get_model(args))


async def _get_deployments(account_id: str):
    # Step 1: Get all deployments
    deployments = []
    deployments_response = await list_deployments(account_id)
    deployments.extend(deployments_response["deployments"])
    pageToken = deployments_response.get("nextPageToken", "")

    while pageToken != "":
        deployments_response = await list_deployments(account_id, pageToken=pageToken)
        deployments.extend(deployments_response["deployments"])
        pageToken = deployments_response.get("nextPageToken", "")

    # Step 2: Extract baseModel from each deployment and call get_model for it
    get_models_coros = []
    for d in deployments:
        base_model = d["baseModel"]
        account_id, model_id = extract_components_from_resource_id(base_model)
        get_models_coros.append(get_model(account_id, model_id))

    gathered_models = await asyncio.gather(*get_models_coros)

    # Step 3: Filter the models where kind == "FLUMINA_BASE_MODEL"
    filtered_deployments = []
    for i, model in enumerate(gathered_models):
        if model["kind"] == "FLUMINA_BASE_MODEL":
            filtered_deployments.append(deployments[i])

    return filtered_deployments


# Deployments CRUD
async def _flumina_list_deployments(args):
    account_id = await resolve_account_id(args)
    gathered_deployments = await _get_deployments(account_id)

    headers = ["account_id", "deployment_id", "state", "base_model_id", "url_prefix"]
    results: List[Tuple[str, str, str, str, str]] = []

    for d in gathered_deployments:
        account_id, deployment_id = extract_components_from_resource_id(
            d["name"], resource_type="deployments"
        )

        state = d["state"]
        base_model_id = d["baseModel"]
        model_account_id, model_id = extract_components_from_resource_id(
            base_model_id, resource_type="models"
        )

        url_prefix = generate_url(model_account_id, model_id, account_id, deployment_id)

        results.append((account_id, deployment_id, state, base_model_id, url_prefix))

    print(tabulate(results, headers=headers, tablefmt="plain"))


def flumina_list_deployments(args):
    return asyncio.run(_flumina_list_deployments(args))


async def _flumina_get_deployment(args):
    user_account_id = await resolve_account_id(args)
    deployment_account_id, deployment_id = resolve_user_scoped_resource_name(
        args.deployment_name, user_account_id, resource_type="deployments"
    )

    response_json = await get_deployment(
        account_id=deployment_account_id,
        deployment_id=deployment_id,
    )

    print(json.dumps(response_json))


def flumina_get_deployment(args):
    return asyncio.run(_flumina_get_deployment(args))


async def get_openapi_json(
    model_account_id: str, model_id: str, account_id: str, deployment_id: str
):
    path_override = (
        f"/v1/workflows/accounts/{model_account_id}/models/{model_id}/openapi.json"
    )
    openapi_url = generate_url(
        model_account_id, model_id, account_id, deployment_id, path_override
    )

    headers = {
        "Authorization": f"Bearer {get_api_key()}",
        "Content-Type": "application/json",
    }

    async with httpx.AsyncClient() as client:
        response = await client.post(
            openapi_url, headers=headers, json={}
        )  # Empty JSON body
        response.raise_for_status()  # Raise exception for any HTTP errors
        return response.json()  # Decode the JSON response


async def _flumina_list_endpoints(args):
    account_id = await resolve_account_id(args)
    gathered_deployments = await _get_deployments(account_id)

    headers = ["account_id", "deployment_id", "path", "url"]
    results: List[Tuple[str, str, str, str, str]] = []

    for d in gathered_deployments:
        account_id, deployment_id = extract_components_from_resource_id(
            d["name"], resource_type="deployments"
        )

        base_model_id = d["baseModel"]
        model_account_id, model_id = extract_components_from_resource_id(
            base_model_id, resource_type="models"
        )

        openapi_spec = await get_openapi_json(
            model_account_id=model_account_id,
            model_id=model_id,
            account_id=account_id,
            deployment_id=deployment_id,
        )

        for path, _ in openapi_spec["paths"].items():
            url = generate_url(
                model_account_id, model_id, account_id, deployment_id, path
            )

            results.append((account_id, deployment_id, path, url))

    print(tabulate(results, headers=headers, tablefmt="plain"))


def flumina_list_endpoints(args):
    return asyncio.run(_flumina_list_endpoints(args))


async def _flumina_get_schema(args):
    user_account_id = await resolve_account_id(args)
    deployment_account_id, deployment_id = resolve_user_scoped_resource_name(
        args.deployment_name, user_account_id, resource_type="deployments"
    )
    d = await get_deployment(deployment_account_id, deployment_id)
    base_model_id = d["baseModel"]
    model_account_id, model_id = extract_components_from_resource_id(
        base_model_id, resource_type="models"
    )

    openapi_spec = await get_openapi_json(
        model_account_id=model_account_id,
        model_id=model_id,
        account_id=deployment_account_id,
        deployment_id=deployment_id,
    )

    if args.format == "openapi":
        print(openapi_spec)
    elif args.format == "curl":
        curl_commands = generate_curl_commands(
            openapi_spec,
            api_url="https://api.fireworks.ai/inference",
            default_headers=[f"-H 'Authorization: Bearer {get_api_key()}'"],
            query_params=[
                f"deployment=accounts/{deployment_account_id}/deployments/{deployment_id}"
            ],
        )
        for command in curl_commands:
            print(textwrap.indent(command, "    ")[4:])
            print()
    else:
        raise ValueError(f"Unexpected format {args.format} specified")


def flumina_get_schema(args):
    return asyncio.run(_flumina_get_schema(args))


def read_flumina_config() -> dict:
    # Get the current working directory
    checkpoint_dir = os.getcwd()

    # Construct the path to "fireworks.json"
    config_path = os.path.join(checkpoint_dir, "fireworks.json")

    # Open and read the JSON file
    with open(config_path, "r") as file:
        config_data = json.load(file)

    return config_data


def build_filename_to_size_map() -> Dict[str, int]:
    # Initialize the map to store filename to size mapping
    filename_to_size = {}

    # Get the current working directory
    top_level_dir = os.getcwd()

    # Define the path to the .fluminaignore file
    fluminaignore_path = os.path.join(top_level_dir, ".fluminaignore")

    # Parse the .fluminaignore file if it exists
    ignore_rules = None
    if os.path.exists(fluminaignore_path):
        ignore_rules = parse_gitignore(fluminaignore_path)

    # Use os.walk to recursively traverse files while avoiding symlink loops
    for root, dirs, files in os.walk(top_level_dir, followlinks=False):
        for file in files:
            file_path = os.path.join(root, file)

            # Skip files that match any rules in .fluminaignore
            if ignore_rules and ignore_rules(file_path):
                continue

            # Ensure no infinite traversal through symlinks
            try:
                file_stat = os.lstat(file_path)
                # Skip if it's a symlink
                if stat.S_ISLNK(file_stat.st_mode):
                    continue
            except OSError as e:
                # If there's an issue accessing the file, skip it
                print(f"Error accessing {file_path}: {e}")
                continue

            # Get the file size and add it to the map
            try:
                file_size = os.path.getsize(file_path)
                relative_path = os.path.relpath(file_path, top_level_dir)
                filename_to_size[relative_path] = file_size
            except OSError as e:
                # Handle any issues accessing the file size
                print(f"Error getting size for {file_path}: {e}")

    return filename_to_size


async def upload_file(client: httpx.AsyncClient, filename: str, gcs_uri: str) -> None:
    # Check if the file exists locally
    if not os.path.exists(filename):
        print(f"File {filename} does not exist. Skipping.")
        return filename, False

    try:
        # Get the file size for progress tracking
        file_size = os.path.getsize(filename)

        # Determine the Content-Type (you can improve this by inferring the type from the file extension)
        content_type = "application/octet-stream"  # Use a default content type

        # Open the file in binary mode and upload it in chunks
        with open(filename, "rb") as file:
            with tqdm.tqdm(
                total=file_size, unit="B", unit_scale=True, desc=filename
            ) as progress_bar:
                # Custom async generator to read the file in chunks and update progress
                async def file_chunk_generator():
                    while True:
                        chunk = await asyncio.to_thread(
                            file.read, 1024 * 1024
                        )  # 1 MB chunks
                        if not chunk:
                            break
                        progress_bar.update(len(chunk))
                        yield chunk

                # Perform the upload using a PUT request to the signed GCS URI with streaming
                print(f"Uploading {filename} to Fireworks...")
                headers = {
                    "Content-Type": content_type,
                    "x-goog-content-length-range": f"{file_size},{file_size}",
                }
                response = await client.put(
                    gcs_uri, data=file_chunk_generator(), headers=headers
                )
                print(f"Done uploading {filename} to Fireworks!")

                # Check the response status
                if response.status_code == 200:
                    print(f"Successfully uploaded {filename}")
                    return filename, True
                else:
                    print(
                        f"Failed to upload {filename}. Status: {response.status_code} {response.content}"
                    )
                    return filename, False

    except Exception as e:
        print(f"Error uploading {filename}: {type(e)} {e}")
        return filename, False


async def upload_files_to_gcs(filename_to_uri: Dict[str, str]) -> None:
    async with httpx.AsyncClient(timeout=None) as client:
        # Create a list of coroutines for each file upload
        upload_tasks = [
            upload_file(client, filename, gcs_uri)
            for filename, gcs_uri in filename_to_uri.items()
        ]

        # Run the upload tasks concurrently
        results = await asyncio.gather(*upload_tasks)

        # Check for any failed uploads
        failed = [r for r in results if not r[1]]
        if len(failed) > 0:
            raise RuntimeError(f"Failed to upload files: {[r[0] for r in failed]}")


async def _flumina_create_model(args):
    user_account_id = await resolve_account_id(args)
    model_account_id, model_id = resolve_user_scoped_resource_name(
        args.model_name, user_account_id, resource_type="models"
    )

    # Create model in control plane db
    model = {}

    flumina_config = read_flumina_config()
    if not flumina_config.get("_is_flumina_model", False):
        raise ValueError(f"Current directory does not contain a Flumina model")

    # TODO:
    # displayName
    # description
    # githubUrl
    # huggingFaceUrl

    addon_type = flumina_config.get("_flumina_addon_type", "")
    if addon_type != "":
        if args.base_model is None:
            raise ValueError(f"Must specify --base-model if uploading an addon")
        split = args.base_model.split("/")
        if len(split) != 4 or split[0] != "accounts" or split[2] != "models":
            raise ValueError(
                f"--base-model must be a resource name like accounts/my-account/models/my-model"
            )

        model["kind"] = "FLUMINA_ADDON"
        model["peftDetails"] = {
            "baseModel": args.base_model,
        }
    else:
        model["kind"] = "FLUMINA_BASE_MODEL"
        model["baseModelDetails"] = {
            "worldSize": args.world_size,
        }

    model["public"] = args.public

    created_model = await create_model(
        account_id=model_account_id,
        model_id=model_id,
        model_data=model,
    )

    filename_to_size: Dict[str, int] = build_filename_to_size_map()

    model_upload_endpoint = await get_model_upload_endpoint(
        account_id=model_account_id,
        model_id=model_id,
        filename_to_size=filename_to_size,
    )
    assert len(model_upload_endpoint["filenameToUnsignedUris"]) == 0
    assert len(model_upload_endpoint["filenameToSignedUrls"]) == len(filename_to_size)

    await upload_files_to_gcs(
        filename_to_uri=model_upload_endpoint["filenameToSignedUrls"]
    )

    await validate_model_upload(account_id=model_account_id, model_id=model_id)


def flumina_create_model(args):
    return asyncio.run(_flumina_create_model(args))


async def _flumina_delete_model(args):
    user_account_id = await resolve_account_id(args)
    model_account_id, model_id = resolve_user_scoped_resource_name(
        args.model_name, user_account_id, resource_type="models"
    )

    await delete_model(account_id=model_account_id, model_id=model_id)


def flumina_delete_model(args):
    return asyncio.run(_flumina_delete_model(args))


async def _flumina_create_deployment(args):
    user_account_id = await resolve_account_id(args)
    model_account_id, model_id = resolve_user_scoped_resource_name(
        args.model_name, user_account_id, resource_type="models"
    )

    model_resource_name = f"accounts/{model_account_id}/models/{model_id}"

    ACCELERATOR_MAP = {
        "H100": "NVIDIA_H100_80GB",
        "A100": "NVIDIA_A100_80GB",
    }

    deployment = {
        "baseModel": model_resource_name,
        "minReplicaCount": args.min_replica_count,
        "maxReplicaCount": args.max_replica_count or max(args.min_replica_count, 1),
        "acceleratorType": ACCELERATOR_MAP[args.accelerator_type],
        "enable_addons": True,
    }
    created_deployment = await create_deployment(
        account_id=user_account_id,
        deployment_data=deployment,
    )
    # TODO: improve this prinout
    print(created_deployment)

    return created_deployment


def flumina_create_deployment(args):
    return asyncio.run(_flumina_create_deployment(args))


async def _flumina_create_deployed_addon(args):
    user_account_id = await resolve_account_id(args)
    addon_account_id, addon_id = resolve_user_scoped_resource_name(
        args.addon_name, user_account_id, resource_type="models"
    )
    deployment_account_id, deployment_id = resolve_user_scoped_resource_name(
        args.deployment_name, user_account_id, resource_type="deployments"
    )

    # Validate addon exists and is the correct  type
    addon = await get_model(addon_account_id, addon_id)
    if addon["kind"] != "FLUMINA_ADDON":
        raise ValueError(
            f"Model {addon_account_id}/{addon_id} is not a Flumina addon (it is a {addon['kind']})"
        )
    base_model_account_id, base_model_id = extract_components_from_resource_id(
        addon["peftDetails"]["baseModel"]
    )

    # Validate deployment exists and the underlying model is the correct type
    deployment = await get_deployment(deployment_account_id, deployment_id)
    model_account_id, model_id = extract_components_from_resource_id(
        deployment["baseModel"]
    )
    model = await get_model(model_account_id, model_id)
    if model["kind"] != "FLUMINA_BASE_MODEL":
        raise ValueError(
            f"Model {model_account_id}/{model_id} deployed on deployment {deployment_account_id}/{deployment_id} is not a Flumina model (it is a {model['kind']})"
        )

    if (base_model_account_id != model_account_id) or (base_model_id != model_id):
        raise ValueError(
            f"Addon {addon_account_id}/{addon_id} expected base model {base_model_account_id}/{base_model_id} but deployment {deployment_account_id}/{deployment_id} has model {model_account_id}/{model_id}"
        )

    await create_deployed_model(
        user_account_id,
        deployed_model_data={
            "model": f"accounts/{addon_account_id}/models/{addon_id}",
            "deployment": f"accounts/{deployment_account_id}/deployments/{deployment_id}",
        },
    )

    # TODO: Poll deployed-model status and return its schema
    # TODO: List and delete addons


def flumina_create_deployed_addon(args):
    return asyncio.run(_flumina_create_deployed_addon(args))


async def _flumina_delete_deployment(args):
    user_account_id = await resolve_account_id(args)
    deployment_account_id, deployment_id = resolve_user_scoped_resource_name(
        args.deployment_name, user_account_id, resource_type="deployments"
    )

    await delete_deployment(
        account_id=deployment_account_id, deployment_id=deployment_id
    )


def flumina_delete_deployment(args):
    return asyncio.run(_flumina_delete_deployment(args))


async def _flumina_deploy(args):
    user_account_id = await resolve_account_id(args)
    model_account_id, model_id = resolve_user_scoped_resource_name(
        args.model_name, user_account_id, resource_type="models"
    )

    try:
        # Check for model existence. If it exists, skip upload.
        await get_model(account_id=model_account_id, model_id=model_id)
        get_logger().info(
            f"Model {model_account_id}/{model_id} already exists. Deploying that one..."
        )
        exists = True
    except httpx.HTTPStatusError as e:
        if e.response.status_code == 404:
            exists = False
        else:
            raise

    if not exists:
        get_logger().info(
            f"Model {model_account_id}/{model_id} does not exist, creating from current directory..."
        )
        if args.skip_validation:
            get_logger().info(f"Skipping app validation as requested")
        else:
            get_logger().info(f"Validating Flumina app...")
            flumina_validate(args)
        get_logger().info(f"Creating Flumina model on Fireworks...")
        await _flumina_create_model(args)

    get_logger().info(f"Deploying Flumina model {model_account_id}/{model_id}...")
    created_deployment = await _flumina_create_deployment(args)
    deployment_acct_id, deployment_id = extract_components_from_resource_id(
        created_deployment["name"], "deployments"
    )

    # Poll until deployment is in READY or failed state
    start_time = time.time()
    while True:
        deployment = await get_deployment(
            account_id=deployment_acct_id,
            deployment_id=deployment_id,
        )
        state = deployment["state"]

        # Overwrite the previous output
        print(
            f"\rWaiting for deployment {deployment_acct_id}/{deployment_id}. Current state: {state}. Elapsed sec: {int(time.time() - start_time)}...",
            end="",
            flush=True,
        )

        if state == "READY":
            break
        elif state in {"STATE_UNSPECIFIED", "CREATING", "UPDATING"}:
            time.sleep(1)
            continue
        else:
            # 'DELETING', 'FAILED', 'DELETED'
            raise RuntimeError(f"Deployment encountered state {state}. Aborting.")

    # Print final status on a new line
    print()  # Move to a new line after the loop

    # Poll until schema endpoint is up
    start_time = time.time()
    while True:
        try:
            print(
                f"\rWaiting for deployment {deployment_acct_id}/{deployment_id} to be reachable. Elapsed sec: {int(time.time() - start_time)}",
                end="",
                flush=True,
            )
            await get_openapi_json(
                model_account_id, model_id, deployment_acct_id, deployment_id
            )
            break
        except httpx.HTTPStatusError as e:
            if e.response.status_code in {404, 503}:
                time.sleep(1)
                continue
            else:
                raise
    print()

    args.deployment_name = f"accounts/{deployment_acct_id}/deployments/{deployment_id}"
    get_logger().info(
        f"Deployment {deployment_acct_id}/{deployment_id} is ready! Try it with the following commands:"
    )
    await _flumina_get_schema(args)


def flumina_deploy(args):
    asyncio.run(_flumina_deploy(args))


# Recursive function to define subcommands
def add_subcommand(subparsers, name, func, help_text, arguments=None):
    parser = subparsers.add_parser(name, help=help_text)
    if arguments:
        for arg_name, arg_params in arguments.items():
            parser.add_argument(arg_name, **arg_params)
    parser.set_defaults(func=func)


def flumina_set_api_key(args):
    if not args.api_key:
        raise ValueError(f"Expected API key to be specified but got {args.api_key}")

    set_api_key(args.api_key)


# Recursive function to create the command tree
def build_command_tree():
    parser = argparse.ArgumentParser(description="Flumina CLI Tool")
    subparsers = parser.add_subparsers(
        dest="command", required=True, help="The Flumina command to run"
    )

    # Command tree structure
    commands = {
        "set-api-key": {
            "help": "Set fireworks API key for accessing Fireworks services.",
            "func": flumina_set_api_key,
            "arguments": {
                "api_key": {
                    "type": str,
                    "help": "The Fireworks API key to write to disk.",
                },
            },
        },
        "init": {
            "help": "Initialize a Flumina app",
            "subcommands": {
                "app": {
                    "func": flumina_init_app,
                    "help": "Initialize an empty Flumina app in the current directory",
                    "arguments": {
                        "--allow-non-empty": {
                            "action": "store_true",
                            "help": "Allow initialization of a Flumina app in a non-empty folder",
                        }
                    },
                },
                "from_hf": {
                    "func": flumina_init_from_hf,
                    "help": "Initialize a Flumina app from the specified HF repo in the current directory",
                    "arguments": {
                        "model_repo": {
                            "type": str,
                            "help": "The Hugging Face app name to initialize from",
                        },
                        "--allow-non-empty": {
                            "action": "store_true",
                            "help": "Allow initialization of a Flumina app in a non-empty folder",
                        },
                    },
                },
                "addon": {
                    "func": flumina_init_addon,
                    "help": "Initialize a Flumina addon repo in the current app",
                    "arguments": {
                        "addon_type": {
                            "type": str,
                            "help": "The addon type to initialize. The possible addon types and their schemas are defined by each base model.",
                        },
                        "--allow-non-empty": {
                            "action": "store_true",
                            "help": "Allow initialization of a Flumina app in a non-empty folder",
                        },
                    },
                },
            },
        },
        "validate": {
            "func": flumina_validate,
            "help": "Validate the Flumina repo in the current directory",
            "arguments": {
                "--world-size": {
                    "type": int,
                    "help": "The distributed world size (# of workers) under which to run "
                            "the app for validation",
                    "default": 1,
                }
            },
        },
        "deploy": {
            "func": flumina_deploy,
            "help": "Validate, upload, deploy, and return schema for the current directory.",
            "arguments": {
                "model_name": {
                    "type": str,
                    "help": "The resource name of the model to be created. Can either be a model id (e.g. my-model) "
                    "or a fully-qualified resource name (e.g. accounts/my-account/models/my-model)",
                },
                "--public": {
                    "action": "store_true",
                    "help": "Set this flag to make the model public",
                },
                "--base-model": {
                    "type": str,
                    "help": "Resource id of the base model to associate with this model, "
                    "e.g. accounts/myaccount/models/mymodel. Must be specified if "
                    "uploading an addon model. Should not be specified otherwise.",
                    "default": None,
                },
                "--world-size": {
                    "type": int,
                    "help": "The distributed world size (# of workers) under which the created "
                            "model should run",
                    "default": 1,
                },
                "--min-replica-count": {
                    "type": int,
                    "help": "Minimum number of replicas for the deployment. Defaults to 0.",
                    "default": 0,
                },
                "--max-replica-count": {
                    "type": int,
                    "help": "Maximum number of replicas for the deployment. If not specified, the default is max(min_replica_count, 1)",
                    "default": None,
                },
                "--accelerator-type": {
                    "type": str,
                    "help": "The type of GPU accelerator on which the deployment should be run. One of H100 or A100. Default H100.",
                    "choices": ["H100", "A100"],
                    "default": "H100",
                },
                "--format": {
                    "type": str,
                    "help": "The format in which to print the deployment's schema",
                    "choices": ["openapi", "curl"],
                    "default": "curl",
                },
                "--skip-validation": {
                    "action": "store_true",
                    "help": "Skip app validation. Not recommended -- only intended for use in automated testing scenarios",
                },
            },
        },
        "get": {
            "help": "Get resources",
            "subcommands": {
                "model": {
                    "func": flumina_get_model,
                    "help": "Get Flumina model",
                    "arguments": {
                        "model_name": {
                            "type": str,
                            "help": "Name of the model to get. Can either be a model id (e.g. my-model) "
                            "or a fully-qualified resource name (e.g. accounts/my-account/models/my-model)",
                        },
                    },
                },
                "deployment": {
                    "func": flumina_get_deployment,
                    "help": "Get Flumina deployment",
                    "arguments": {
                        "deployment_name": {
                            "type": str,
                            "help": "Resource ID of the deployment to look up. Can either be a deployment id (e.g. 012456) "
                            "or a fully-qualified resource name (e.g. accounts/my-accounts/deployments/0123456)",
                        },
                    },
                },
                "schema": {
                    "func": flumina_get_schema,
                    "help": "Get schema from a specified Flumina deployment",
                    "arguments": {
                        "deployment_name": {
                            "type": str,
                            "help": "Resource ID of the deployment to look up. Can either be a deployment id (e.g. 012456) "
                            "or a fully-qualified resource name (e.g. accounts/my-accounts/deployments/0123456)",
                        },
                        "--format": {
                            "type": str,
                            "help": "The format in which to print the deployment's schema",
                            "choices": ["openapi", "curl"],
                            "default": "openapi",
                        },
                    },
                },
            },
        },
        "list": {
            "help": "List resources",
            "subcommands": {
                "models": {
                    "func": flumina_list_models,
                    "help": "List Flumina models",
                    "arguments": {
                        "--account_id": {
                            "type": str,
                            "help": "The Fireworks account ID to use for looking up the resources.",
                            "required": False,
                        }
                    },
                },
                "deployments": {
                    "func": flumina_list_deployments,
                    "help": "List Flumina deployments",
                    "arguments": {
                        "--account_id": {
                            "type": str,
                            "help": "The Fireworks account ID to use for looking up the resources.",
                            "required": False,
                        }
                    },
                },
                "endpoints": {
                    "func": flumina_list_endpoints,
                    "help": "List endpoints",
                    "arguments": {
                        "--account_id": {
                            "type": str,
                            "help": "The Fireworks account ID to use for looking up the resources.",
                            "required": False,
                        }
                    },
                },
            },
        },
        "create": {
            "help": "Create resources",
            "subcommands": {
                "model": {
                    "func": flumina_create_model,
                    "help": "Upload the current directory to Fireworks as a Flumina model",
                    "arguments": {
                        "model_name": {
                            "type": str,
                            "help": "The resource name of the model to be created. Can either be a model id (e.g. my-model) "
                            "or a fully-qualified resource name (e.g. accounts/my-account/models/my-model)",
                        },
                        "--base-model": {
                            "type": str,
                            "help": "Resource id of the base model to associate with this model, "
                            "e.g. accounts/myaccount/models/mymodel. Must be specified if "
                            "uploading an addon model. Should not be specified otherwise.",
                            "default": None,
                        },
                        "--public": {
                            "action": "store_true",
                            "help": "Set this flag to make the model public",
                        },
                        "--world-size": {
                            "type": int,
                            "help": "The distributed world size (# of workers) under which the created "
                                    "model should run",
                            "default": 1,
                        },
                    },
                },
                "deployment": {
                    "func": flumina_create_deployment,
                    "help": "Deploy an existing Flumina model",
                    "arguments": {
                        "model_name": {
                            "type": str,
                            "help": "The resource name of the model to deploy. Can either be a model id (e.g. my-model) "
                            "or a fully-qualified resource name (e.g. accounts/my-account/models/my-model)",
                        },
                        "--min-replica-count": {
                            "type": int,
                            "help": "Minimum number of replicas for the deployment. Defaults to 0.",
                            "default": 0,
                        },
                        "--max-replica-count": {
                            "type": int,
                            "help": "Maximum number of replicas for the deployment. If not specified, the default is max(min_replica_count, 1)",
                            "default": None,
                        },
                        "--accelerator-type": {
                            "type": str,
                            "help": "The type of GPU accelerator on which the deployment should be run. One of H100 or A100. Default H100.",
                            "choices": ["H100", "A100"],
                            "default": "H100",
                        },
                    },
                },
                "deployed_addon": {
                    "func": flumina_create_deployed_addon,
                    "help": "Deploy an existing Flumina add-on to an existing deployment",
                    "arguments": {
                        "addon_name": {
                            "type": str,
                            "help": "The resource name of the addon to deploy. Can either be a model id (e.g. my-model) "
                            "or a fully-qualified resource name (e.g. accounts/my-account/models/my-model)",
                        },
                        "deployment_name": {
                            "type": str,
                            "help": "The resource name of the deployment on which to deploy the addon. Can either be a deployment id (e.g. 0123456) "
                            "or a fully-qualified resource name (e.g. accounts/my-account/deployments/0123456)",
                        },
                    },
                },
            },
        },
        "delete": {
            "help": "Delete resources",
            "subcommands": {
                "model": {
                    "func": flumina_delete_model,
                    "help": "Delete an existing Flumina model",
                    "arguments": {
                        "model_name": {
                            "type": str,
                            "help": "Model ID of the model to create",
                        },
                    },
                },
                "deployment": {
                    "func": flumina_delete_deployment,
                    "help": "Delete an existing Flumina deployment",
                    "arguments": {
                        "deployment_name": {
                            "type": str,
                            "help": "Resource ID of the deployment to delete. Can either be a deployment id (e.g. 012456) "
                            "or a fully-qualified resource name (e.g. accounts/my-accounts/deployments/0123456)",
                        },
                    },
                },
            },
        },
    }

    def add_commands(subparsers, command_dict):
        for cmd_name, cmd_info in command_dict.items():
            if "subcommands" in cmd_info:
                sub_parser = subparsers.add_parser(cmd_name, help=cmd_info["help"])
                sub_subparsers = sub_parser.add_subparsers(
                    dest="subcommand", required=True
                )
                add_commands(sub_subparsers, cmd_info["subcommands"])
            else:
                add_subcommand(
                    subparsers,
                    cmd_name,
                    cmd_info["func"],
                    cmd_info["help"],
                    cmd_info.get("arguments"),
                )

    add_commands(subparsers, commands)

    return parser


def main():
    # Build and parse arguments
    parser = build_command_tree()
    args = parser.parse_args()

    # Call the corresponding function
    if hasattr(args, "func"):
        args.func(args)
    else:
        parser.print_help()


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gateway/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gateway/snapshot.proto',
  package='gateway',
  syntax='proto3',
  serialized_options=b'Z\n./;gateway',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16gateway/snapshot.proto\x12\x07gateway\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa0\x02\n\x08Snapshot\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\x12\x37\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xe0\x41\x03\xe0\x41\x05\x12.\n\x05state\x18\x03 \x01(\x0e\x32\x17.gateway.Snapshot.StateB\x06\xe0\x41\x03\xe0\x41\x05\x12\'\n\x06status\x18\x04 \x01(\x0b\x32\x0f.gateway.StatusB\x06\xe0\x41\x03\xe0\x41\x05\x12\x19\n\timage_ref\x18\x05 \x01(\tB\x06\xe0\x41\x03\xe0\x41\x05\"Q\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\"V\n\x15\x43reateSnapshotRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12(\n\x08snapshot\x18\x02 \x01(\x0b\x32\x11.gateway.SnapshotB\x03\xe0\x41\x02\"\'\n\x12GetSnapshotRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\"\x88\x01\n\x14ListSnapshotsRequest\x12\x13\n\x06parent\x18\x01 \x01(\tB\x03\xe0\x41\x02\x12\x16\n\tpage_size\x18\x02 \x01(\x05\x42\x03\xe0\x41\x01\x12\x17\n\npage_token\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12\x13\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xe0\x41\x01\x12\x15\n\x08order_by\x18\x05 \x01(\tB\x03\xe0\x41\x01\"j\n\x15ListSnapshotsResponse\x12$\n\tsnapshots\x18\x01 \x03(\x0b\x32\x11.gateway.Snapshot\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"*\n\x15\x44\x65leteSnapshotRequest\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x02\x42\x0cZ\n./;gatewayb\x06proto3'
  ,
  dependencies=[gateway_dot_status__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_SNAPSHOT_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='gateway.Snapshot.State',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=331,
  serialized_end=412,
)
_sym_db.RegisterEnumDescriptor(_SNAPSHOT_STATE)


_SNAPSHOT = _descriptor.Descriptor(
  name='Snapshot',
  full_name='gateway.Snapshot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.Snapshot.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='gateway.Snapshot.create_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='gateway.Snapshot.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='gateway.Snapshot.status', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_ref', full_name='gateway.Snapshot.image_ref', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\003\340A\005', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SNAPSHOT_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=412,
)


_CREATESNAPSHOTREQUEST = _descriptor.Descriptor(
  name='CreateSnapshotRequest',
  full_name='gateway.CreateSnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.CreateSnapshotRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='gateway.CreateSnapshotRequest.snapshot', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=500,
)


_GETSNAPSHOTREQUEST = _descriptor.Descriptor(
  name='GetSnapshotRequest',
  full_name='gateway.GetSnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.GetSnapshotRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=541,
)


_LISTSNAPSHOTSREQUEST = _descriptor.Descriptor(
  name='ListSnapshotsRequest',
  full_name='gateway.ListSnapshotsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='gateway.ListSnapshotsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='gateway.ListSnapshotsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='gateway.ListSnapshotsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='gateway.ListSnapshotsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='gateway.ListSnapshotsRequest.order_by', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=544,
  serialized_end=680,
)


_LISTSNAPSHOTSRESPONSE = _descriptor.Descriptor(
  name='ListSnapshotsResponse',
  full_name='gateway.ListSnapshotsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshots', full_name='gateway.ListSnapshotsResponse.snapshots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='gateway.ListSnapshotsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_size', full_name='gateway.ListSnapshotsResponse.total_size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=788,
)


_DELETESNAPSHOTREQUEST = _descriptor.Descriptor(
  name='DeleteSnapshotRequest',
  full_name='gateway.DeleteSnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='gateway.DeleteSnapshotRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\340A\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=790,
  serialized_end=832,
)

_SNAPSHOT.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SNAPSHOT.fields_by_name['state'].enum_type = _SNAPSHOT_STATE
_SNAPSHOT.fields_by_name['status'].message_type = gateway_dot_status__pb2._STATUS
_SNAPSHOT_STATE.containing_type = _SNAPSHOT
_CREATESNAPSHOTREQUEST.fields_by_name['snapshot'].message_type = _SNAPSHOT
_LISTSNAPSHOTSRESPONSE.fields_by_name['snapshots'].message_type = _SNAPSHOT
DESCRIPTOR.message_types_by_name['Snapshot'] = _SNAPSHOT
DESCRIPTOR.message_types_by_name['CreateSnapshotRequest'] = _CREATESNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['GetSnapshotRequest'] = _GETSNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['ListSnapshotsRequest'] = _LISTSNAPSHOTSREQUEST
DESCRIPTOR.message_types_by_name['ListSnapshotsResponse'] = _LISTSNAPSHOTSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSnapshotRequest'] = _DELETESNAPSHOTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Snapshot = _reflection.GeneratedProtocolMessageType('Snapshot', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOT,
  '__module__' : 'gateway.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:gateway.Snapshot)
  })
_sym_db.RegisterMessage(Snapshot)

CreateSnapshotRequest = _reflection.GeneratedProtocolMessageType('CreateSnapshotRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESNAPSHOTREQUEST,
  '__module__' : 'gateway.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:gateway.CreateSnapshotRequest)
  })
_sym_db.RegisterMessage(CreateSnapshotRequest)

GetSnapshotRequest = _reflection.GeneratedProtocolMessageType('GetSnapshotRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSNAPSHOTREQUEST,
  '__module__' : 'gateway.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:gateway.GetSnapshotRequest)
  })
_sym_db.RegisterMessage(GetSnapshotRequest)

ListSnapshotsRequest = _reflection.GeneratedProtocolMessageType('ListSnapshotsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSREQUEST,
  '__module__' : 'gateway.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListSnapshotsRequest)
  })
_sym_db.RegisterMessage(ListSnapshotsRequest)

ListSnapshotsResponse = _reflection.GeneratedProtocolMessageType('ListSnapshotsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSNAPSHOTSRESPONSE,
  '__module__' : 'gateway.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:gateway.ListSnapshotsResponse)
  })
_sym_db.RegisterMessage(ListSnapshotsResponse)

DeleteSnapshotRequest = _reflection.GeneratedProtocolMessageType('DeleteSnapshotRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESNAPSHOTREQUEST,
  '__module__' : 'gateway.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:gateway.DeleteSnapshotRequest)
  })
_sym_db.RegisterMessage(DeleteSnapshotRequest)


DESCRIPTOR._options = None
_SNAPSHOT.fields_by_name['name']._options = None
_SNAPSHOT.fields_by_name['create_time']._options = None
_SNAPSHOT.fields_by_name['state']._options = None
_SNAPSHOT.fields_by_name['status']._options = None
_SNAPSHOT.fields_by_name['image_ref']._options = None
_CREATESNAPSHOTREQUEST.fields_by_name['parent']._options = None
_CREATESNAPSHOTREQUEST.fields_by_name['snapshot']._options = None
_GETSNAPSHOTREQUEST.fields_by_name['name']._options = None
_LISTSNAPSHOTSREQUEST.fields_by_name['parent']._options = None
_LISTSNAPSHOTSREQUEST.fields_by_name['page_size']._options = None
_LISTSNAPSHOTSREQUEST.fields_by_name['page_token']._options = None
_LISTSNAPSHOTSREQUEST.fields_by_name['filter']._options = None
_LISTSNAPSHOTSREQUEST.fields_by_name['order_by']._options = None
_DELETESNAPSHOTREQUEST.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
